==> aws-android-sdk-s3-2.1.7-sources.jar: main/java/com/amazonaws/services/ec2/model/transform/GetPasswordDataResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import javax.xml.stream.events.XMLEvent;

import com.amazonaws.services.ec2.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Get Password Data Result StAX Unmarshaller
 */
public class GetPasswordDataResultStaxUnmarshaller implements Unmarshaller<GetPasswordDataResult, StaxUnmarshallerContext> {

    public GetPasswordDataResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        GetPasswordDataResult getPasswordDataResult = new GetPasswordDataResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 1;

        while (true) {
            XMLEvent xmlEvent = context.nextEvent();
            if (xmlEvent.isEndDocument()) return getPasswordDataResult;

            if (xmlEvent.isAttribute() || xmlEvent.isStartElement()) {
                if (context.testExpression("instanceId", targetDepth)) {
                    getPasswordDataResult.setInstanceId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("timestamp", targetDepth)) {
                    getPasswordDataResult.setTimestamp(DateStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("passwordData", targetDepth)) {
                    getPasswordDataResult.setPasswordData(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent.isEndElement()) {
                if (context.getCurrentDepth() < originalDepth) {
                    return getPasswordDataResult;
                }
            }
        }
    }

    private static GetPasswordDataResultStaxUnmarshaller instance;
    public static GetPasswordDataResultStaxUnmarshaller getInstance() {
        if (instance == null) instance = new GetPasswordDataResultStaxUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-s3-2.1.8-sources.jar: main/java/com/amazonaws/services/ec2/model/transform/GetPasswordDataResultStaxUnmarshaller.java <==
/*
 * Copyright 2010-2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.ec2.model.transform;

import java.util.Map;
import java.util.Map.Entry;

import org.xmlpull.v1.XmlPullParser;

import com.amazonaws.services.ec2.model.*;
import com.amazonaws.transform.Unmarshaller;
import com.amazonaws.transform.MapEntry;
import com.amazonaws.transform.StaxUnmarshallerContext;
import com.amazonaws.transform.SimpleTypeStaxUnmarshallers.*;

/**
 * Get Password Data Result StAX Unmarshaller
 */
public class GetPasswordDataResultStaxUnmarshaller implements Unmarshaller<GetPasswordDataResult, StaxUnmarshallerContext> {

    public GetPasswordDataResult unmarshall(StaxUnmarshallerContext context) throws Exception {
        GetPasswordDataResult getPasswordDataResult = new GetPasswordDataResult();
        int originalDepth = context.getCurrentDepth();
        int targetDepth = originalDepth + 1;

        if (context.isStartOfDocument()) targetDepth += 1;

        while (true) {
            int xmlEvent = context.nextEvent();
            if (xmlEvent == XmlPullParser.END_DOCUMENT) return getPasswordDataResult;

            if (xmlEvent == XmlPullParser.START_TAG) {
                if (context.testExpression("instanceId", targetDepth)) {
                    getPasswordDataResult.setInstanceId(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("timestamp", targetDepth)) {
                    getPasswordDataResult.setTimestamp(DateStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
                if (context.testExpression("passwordData", targetDepth)) {
                    getPasswordDataResult.setPasswordData(StringStaxUnmarshaller.getInstance().unmarshall(context));
                    continue;
                }
            } else if (xmlEvent == XmlPullParser.END_TAG) {
                if (context.getCurrentDepth() < originalDepth) {
                    return getPasswordDataResult;
                }
            }
        }
    }

    private static GetPasswordDataResultStaxUnmarshaller instance;
    public static GetPasswordDataResultStaxUnmarshaller getInstance() {
        if (instance == null) instance = new GetPasswordDataResultStaxUnmarshaller();
        return instance;
    }
}
